@@ -1,5 +1,9 @@
 from enum import Enum
 
+NUMPY_atol = 1e-8
+FLOAT_atol = 1e-12
+
+
 class TreeBasedDriftValueType(Enum):
     NODE_SIZE = "node_size"
     MEAN = "mean"
